=========
Changelog
=========

1.1.0 (2024-05-06)
------------------

* Use ``os.execvpe()`` to launch Harlequin, which replaces the Django process, reducing overall memory usage.

1.0.0 (2024-05-05)
------------------

* Initial release.
